# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from fxsdk.x.cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmos/gov/v1/query.proto\x12\rcosmos.gov.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17\x63osmos/gov/v1/gov.proto\x1a\x19\x63osmos_proto/cosmos.proto\"+\n\x14QueryProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"B\n\x15QueryProposalResponse\x12)\n\x08proposal\x18\x01 \x01(\x0b\x32\x17.cosmos.gov.v1.Proposal\"\xe1\x01\n\x15QueryProposalsRequest\x12\x36\n\x0fproposal_status\x18\x01 \x01(\x0e\x32\x1d.cosmos.gov.v1.ProposalStatus\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\tdepositor\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x16QueryProposalsResponse\x12*\n\tproposals\x18\x01 \x03(\x0b\x32\x17.cosmos.gov.v1.Proposal\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"P\n\x10QueryVoteRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"6\n\x11QueryVoteResponse\x12!\n\x04vote\x18\x01 \x01(\x0b\x32\x13.cosmos.gov.v1.Vote\"d\n\x11QueryVotesRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"u\n\x12QueryVotesResponse\x12\"\n\x05votes\x18\x01 \x03(\x0b\x32\x13.cosmos.gov.v1.Vote\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\")\n\x12QueryParamsRequest\x12\x13\n\x0bparams_type\x18\x01 \x01(\t\"\xb1\x01\n\x13QueryParamsResponse\x12\x32\n\rvoting_params\x18\x01 \x01(\x0b\x32\x1b.cosmos.gov.v1.VotingParams\x12\x34\n\x0e\x64\x65posit_params\x18\x02 \x01(\x0b\x32\x1c.cosmos.gov.v1.DepositParams\x12\x30\n\x0ctally_params\x18\x03 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyParams\"W\n\x13QueryDepositRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"?\n\x14QueryDepositResponse\x12\'\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\x16.cosmos.gov.v1.Deposit\"g\n\x14QueryDepositsRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x15QueryDepositsResponse\x12(\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x16.cosmos.gov.v1.Deposit\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\".\n\x17QueryTallyResultRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"E\n\x18QueryTallyResultResponse\x12)\n\x05tally\x18\x01 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyResult2\xda\x08\n\x05Query\x12\x85\x01\n\x08Proposal\x12#.cosmos.gov.v1.QueryProposalRequest\x1a$.cosmos.gov.v1.QueryProposalResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/gov/v1/proposals/{proposal_id}\x12z\n\tProposals\x12$.cosmos.gov.v1.QueryProposalsRequest\x1a%.cosmos.gov.v1.QueryProposalsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cosmos/gov/v1/proposals\x12\x87\x01\n\x04Vote\x12\x1f.cosmos.gov.v1.QueryVoteRequest\x1a .cosmos.gov.v1.QueryVoteResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/gov/v1/proposals/{proposal_id}/votes/{voter}\x12\x82\x01\n\x05Votes\x12 .cosmos.gov.v1.QueryVotesRequest\x1a!.cosmos.gov.v1.QueryVotesResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/gov/v1/proposals/{proposal_id}/votes\x12|\n\x06Params\x12!.cosmos.gov.v1.QueryParamsRequest\x1a\".cosmos.gov.v1.QueryParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/gov/v1/params/{params_type}\x12\x97\x01\n\x07\x44\x65posit\x12\".cosmos.gov.v1.QueryDepositRequest\x1a#.cosmos.gov.v1.QueryDepositResponse\"C\x82\xd3\xe4\x93\x02=\x12;/cosmos/gov/v1/proposals/{proposal_id}/deposits/{depositor}\x12\x8e\x01\n\x08\x44\x65posits\x12#.cosmos.gov.v1.QueryDepositsRequest\x1a$.cosmos.gov.v1.QueryDepositsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/gov/v1/proposals/{proposal_id}/deposits\x12\x94\x01\n\x0bTallyResult\x12&.cosmos.gov.v1.QueryTallyResultRequest\x1a\'.cosmos.gov.v1.QueryTallyResultResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/gov/v1/proposals/{proposal_id}/tallyB-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _QUERYPROPOSALSREQUEST.fields_by_name['voter']._options = None
  _QUERYPROPOSALSREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYPROPOSALSREQUEST.fields_by_name['depositor']._options = None
  _QUERYPROPOSALSREQUEST.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVOTEREQUEST.fields_by_name['voter']._options = None
  _QUERYVOTEREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDEPOSITREQUEST.fields_by_name['depositor']._options = None
  _QUERYDEPOSITREQUEST.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERY.methods_by_name['Proposal']._options = None
  _QUERY.methods_by_name['Proposal']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/gov/v1/proposals/{proposal_id}'
  _QUERY.methods_by_name['Proposals']._options = None
  _QUERY.methods_by_name['Proposals']._serialized_options = b'\202\323\344\223\002\032\022\030/cosmos/gov/v1/proposals'
  _QUERY.methods_by_name['Vote']._options = None
  _QUERY.methods_by_name['Vote']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/gov/v1/proposals/{proposal_id}/votes/{voter}'
  _QUERY.methods_by_name['Votes']._options = None
  _QUERY.methods_by_name['Votes']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/gov/v1/proposals/{proposal_id}/votes'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002%\022#/cosmos/gov/v1/params/{params_type}'
  _QUERY.methods_by_name['Deposit']._options = None
  _QUERY.methods_by_name['Deposit']._serialized_options = b'\202\323\344\223\002=\022;/cosmos/gov/v1/proposals/{proposal_id}/deposits/{depositor}'
  _QUERY.methods_by_name['Deposits']._options = None
  _QUERY.methods_by_name['Deposits']._serialized_options = b'\202\323\344\223\0021\022//cosmos/gov/v1/proposals/{proposal_id}/deposits'
  _QUERY.methods_by_name['TallyResult']._options = None
  _QUERY.methods_by_name['TallyResult']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/gov/v1/proposals/{proposal_id}/tally'
  _globals['_QUERYPROPOSALREQUEST']._serialized_start=170
  _globals['_QUERYPROPOSALREQUEST']._serialized_end=213
  _globals['_QUERYPROPOSALRESPONSE']._serialized_start=215
  _globals['_QUERYPROPOSALRESPONSE']._serialized_end=281
  _globals['_QUERYPROPOSALSREQUEST']._serialized_start=284
  _globals['_QUERYPROPOSALSREQUEST']._serialized_end=509
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_start=512
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_end=641
  _globals['_QUERYVOTEREQUEST']._serialized_start=643
  _globals['_QUERYVOTEREQUEST']._serialized_end=723
  _globals['_QUERYVOTERESPONSE']._serialized_start=725
  _globals['_QUERYVOTERESPONSE']._serialized_end=779
  _globals['_QUERYVOTESREQUEST']._serialized_start=781
  _globals['_QUERYVOTESREQUEST']._serialized_end=881
  _globals['_QUERYVOTESRESPONSE']._serialized_start=883
  _globals['_QUERYVOTESRESPONSE']._serialized_end=1000
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1002
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1043
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1046
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1223
  _globals['_QUERYDEPOSITREQUEST']._serialized_start=1225
  _globals['_QUERYDEPOSITREQUEST']._serialized_end=1312
  _globals['_QUERYDEPOSITRESPONSE']._serialized_start=1314
  _globals['_QUERYDEPOSITRESPONSE']._serialized_end=1377
  _globals['_QUERYDEPOSITSREQUEST']._serialized_start=1379
  _globals['_QUERYDEPOSITSREQUEST']._serialized_end=1482
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_start=1484
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_end=1610
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_start=1612
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_end=1658
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_start=1660
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_end=1729
  _globals['_QUERY']._serialized_start=1732
  _globals['_QUERY']._serialized_end=2846
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66x/dex/v1/params.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xdc\x03\n\x06Params\x12\x35\n\x08\x66\x65\x65_rate\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12/\n\'force_liquidation_margin_rate_threshold\x18\x02 \x01(\x03\x12\x1b\n\x13max_deals_per_block\x18\x03 \x01(\x03\x12\x1e\n\x16max_orders_per_account\x18\x04 \x01(\x03\x12\x1e\n\x16permitted_max_leverage\x18\x05 \x01(\x03\x12=\n\x10lock_coin_factor\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x38\n\x0b\x66x_discount\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x16\n\x0e\x64iscount_denom\x18\x08 \x01(\t\x12=\n\x10min_funding_rate\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12=\n\x10max_funding_rate\x18\n \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"\x8b\x03\n\x07Reserve\x12\x65\n\x10\x61\x63\x63umulative_fee\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x39\n\x0crisk_reserve\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x61\n\x0clocked_funds\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12=\n\x10short_pay_margin\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12<\n\x0flong_pay_margin\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecB-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _PARAMS.fields_by_name['fee_rate']._options = None
  _PARAMS.fields_by_name['fee_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _PARAMS.fields_by_name['lock_coin_factor']._options = None
  _PARAMS.fields_by_name['lock_coin_factor']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _PARAMS.fields_by_name['fx_discount']._options = None
  _PARAMS.fields_by_name['fx_discount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _PARAMS.fields_by_name['min_funding_rate']._options = None
  _PARAMS.fields_by_name['min_funding_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _PARAMS.fields_by_name['max_funding_rate']._options = None
  _PARAMS.fields_by_name['max_funding_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _RESERVE.fields_by_name['accumulative_fee']._options = None
  _RESERVE.fields_by_name['accumulative_fee']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _RESERVE.fields_by_name['risk_reserve']._options = None
  _RESERVE.fields_by_name['risk_reserve']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _RESERVE.fields_by_name['locked_funds']._options = None
  _RESERVE.fields_by_name['locked_funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _RESERVE.fields_by_name['short_pay_margin']._options = None
  _RESERVE.fields_by_name['short_pay_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _RESERVE.fields_by_name['long_pay_margin']._options = None
  _RESERVE.fields_by_name['long_pay_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PARAMS']._serialized_start=92
  _globals['_PARAMS']._serialized_end=568
  _globals['_RESERVE']._serialized_start=571
  _globals['_RESERVE']._serialized_end=966
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/legacy/other/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66x/legacy/other/query.proto\x12\x08\x66x.other\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"\x11\n\x0fGasPriceRequest\"\x88\x01\n\x10GasPriceResponse\x12t\n\ngas_prices\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xc8\xde\x1f\x00\xf2\xde\x1f\x11yaml:\"gas_prices\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xc9\x01\n\x05Query\x12`\n\nFxGasPrice\x12\x19.fx.other.GasPriceRequest\x1a\x1a.fx.other.GasPriceResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/fx/other/gas_price\x12^\n\x08GasPrice\x12\x19.fx.other.GasPriceRequest\x1a\x1a.fx.other.GasPriceResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/other/v1/gas_priceB=Z;github.com/functionx/fx-core/server/grpc/gasprice/legacy/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.legacy.other.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/functionx/fx-core/server/grpc/gasprice/legacy/v1'
  _GASPRICERESPONSE.fields_by_name['gas_prices']._options = None
  _GASPRICERESPONSE.fields_by_name['gas_prices']._serialized_options = b'\310\336\037\000\362\336\037\021yaml:\"gas_prices\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERY.methods_by_name['FxGasPrice']._options = None
  _QUERY.methods_by_name['FxGasPrice']._serialized_options = b'\202\323\344\223\002\025\022\023/fx/other/gas_price'
  _QUERY.methods_by_name['GasPrice']._options = None
  _QUERY.methods_by_name['GasPrice']._serialized_options = b'\202\323\344\223\002\025\022\023/other/v1/gas_price'
  _globals['_GASPRICEREQUEST']._serialized_start=125
  _globals['_GASPRICEREQUEST']._serialized_end=142
  _globals['_GASPRICERESPONSE']._serialized_start=145
  _globals['_GASPRICERESPONSE']._serialized_end=281
  _globals['_QUERY']._serialized_start=284
  _globals['_QUERY']._serialized_end=485
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from fxsdk.x.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63osmos/gov/v1/tx.proto\x12\rcosmos.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/gov/v1/gov.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xc2\x01\n\x11MsgSubmitProposal\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x38\n\x0finitial_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12*\n\x08proposer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x04 \x01(\t:\r\x82\xe7\xb0*\x08proposer\"0\n\x19MsgSubmitProposalResponse\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"m\n\x14MsgExecLegacyContent\x12\x32\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x0b\xca\xb4-\x07\x43ontent\x12\x11\n\tauthority\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgExecLegacyContentResponse\"\xa1\x01\n\x07MsgVote\x12$\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x0f\xea\xde\x1f\x0bproposal_id\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x06option\x18\x03 \x01(\x0e\x32\x19.cosmos.gov.v1.VoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:\n\x82\xe7\xb0*\x05voter\"\x11\n\x0fMsgVoteResponse\"\xb2\x01\n\x0fMsgVoteWeighted\x12$\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x0f\xea\xde\x1f\x0bproposal_id\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x07options\x18\x03 \x03(\x0b\x32!.cosmos.gov.v1.WeightedVoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:\n\x82\xe7\xb0*\x05voter\"\x19\n\x17MsgVoteWeightedResponse\"\xa0\x01\n\nMsgDeposit\x12$\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x0f\xea\xde\x1f\x0bproposal_id\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12/\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tdepositor\"\x14\n\x12MsgDepositResponse2\xab\x03\n\x03Msg\x12\\\n\x0eSubmitProposal\x12 .cosmos.gov.v1.MsgSubmitProposal\x1a(.cosmos.gov.v1.MsgSubmitProposalResponse\x12\x65\n\x11\x45xecLegacyContent\x12#.cosmos.gov.v1.MsgExecLegacyContent\x1a+.cosmos.gov.v1.MsgExecLegacyContentResponse\x12>\n\x04Vote\x12\x16.cosmos.gov.v1.MsgVote\x1a\x1e.cosmos.gov.v1.MsgVoteResponse\x12V\n\x0cVoteWeighted\x12\x1e.cosmos.gov.v1.MsgVoteWeighted\x1a&.cosmos.gov.v1.MsgVoteWeightedResponse\x12G\n\x07\x44\x65posit\x12\x19.cosmos.gov.v1.MsgDeposit\x1a!.cosmos.gov.v1.MsgDepositResponseB-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000'
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUBMITPROPOSAL._options = None
  _MSGSUBMITPROPOSAL._serialized_options = b'\202\347\260*\010proposer'
  _MSGEXECLEGACYCONTENT.fields_by_name['content']._options = None
  _MSGEXECLEGACYCONTENT.fields_by_name['content']._serialized_options = b'\312\264-\007Content'
  _MSGEXECLEGACYCONTENT._options = None
  _MSGEXECLEGACYCONTENT._serialized_options = b'\202\347\260*\tauthority'
  _MSGVOTE.fields_by_name['proposal_id']._options = None
  _MSGVOTE.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id'
  _MSGVOTE.fields_by_name['voter']._options = None
  _MSGVOTE.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTE._options = None
  _MSGVOTE._serialized_options = b'\202\347\260*\005voter'
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id'
  _MSGVOTEWEIGHTED.fields_by_name['voter']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTEWEIGHTED._options = None
  _MSGVOTEWEIGHTED._serialized_options = b'\202\347\260*\005voter'
  _MSGDEPOSIT.fields_by_name['proposal_id']._options = None
  _MSGDEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id'
  _MSGDEPOSIT.fields_by_name['depositor']._options = None
  _MSGDEPOSIT.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGDEPOSIT.fields_by_name['amount']._options = None
  _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGDEPOSIT._options = None
  _MSGDEPOSIT._serialized_options = b'\202\347\260*\tdepositor'
  _globals['_MSGSUBMITPROPOSAL']._serialized_start=200
  _globals['_MSGSUBMITPROPOSAL']._serialized_end=394
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_start=396
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_end=444
  _globals['_MSGEXECLEGACYCONTENT']._serialized_start=446
  _globals['_MSGEXECLEGACYCONTENT']._serialized_end=555
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_start=557
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_end=587
  _globals['_MSGVOTE']._serialized_start=590
  _globals['_MSGVOTE']._serialized_end=751
  _globals['_MSGVOTERESPONSE']._serialized_start=753
  _globals['_MSGVOTERESPONSE']._serialized_end=770
  _globals['_MSGVOTEWEIGHTED']._serialized_start=773
  _globals['_MSGVOTEWEIGHTED']._serialized_end=951
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_start=953
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_end=978
  _globals['_MSGDEPOSIT']._serialized_start=981
  _globals['_MSGDEPOSIT']._serialized_end=1141
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=1143
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=1163
  _globals['_MSG']._serialized_start=1166
  _globals['_MSG']._serialized_end=1593
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: marginx/oracle/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmarginx/oracle/v1/types.proto\x12\x11marginx.oracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"$\n\x06Params\x12\x1a\n\x12price_quote_symbol\x18\x01 \x01(\t\"\xbf\x01\n\x06Market\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x12\n\nbase_asset\x18\x02 \x01(\t\x12\x13\n\x0bquote_asset\x18\x03 \x01(\t\x12\x36\n\rmarket_status\x18\x05 \x01(\x0e\x32\x1f.marginx.oracle.v1.MarketStatus\x12\x15\n\rprice_decimal\x18\x06 \x01(\x03\x12\x18\n\x10position_decimal\x18\x07 \x01(\x03\x12\x12\n\x04type\x18\x08 \x01(\tB\x04\xc8\xde\x1f\x01\"[\n\x06\x41nswer\x12\x0e\n\x06oracle\x18\x01 \x01(\t\x12\x41\n\x06\x61nswer\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"Y\n\x05Price\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"\xb7\x01\n\nAggregator\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x35\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.marginx.oracle.v1.OracleConfigB\x04\xc8\xde\x1f\x00\x12\x18\n\x10round_start_time\x18\x03 \x01(\x03\x12\x34\n\x0bsubmissions\x18\x04 \x03(\x0b\x32\x19.marginx.oracle.v1.AnswerB\x04\xc8\xde\x1f\x00\x12\x12\n\x04type\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01\"Z\n\x0cOracleConfig\x12\x0f\n\x07oracles\x18\x01 \x03(\t\x12\x1c\n\x14min_answer_threshold\x18\x02 \x01(\r\x12\x1b\n\x13staleness_threshold\x18\x03 \x01(\x03*\xe6\x01\n\x0cMarketStatus\x12\x34\n\x19MARKET_STATUS_UNSPECIFIED\x10\x00\x1a\x15\x8a\x9d \x11MarketStatusEmpty\x12\x30\n\x14MARKET_STATUS_LISTED\x10\x01\x1a\x16\x8a\x9d \x12MarketStatusListed\x12\x32\n\x15MARKET_STATUS_SUSPEND\x10\x02\x1a\x17\x8a\x9d \x13MarketStatusSuspend\x12\x30\n\x14MARKET_STATUS_PRESET\x10\x03\x1a\x16\x8a\x9d \x12MarketStatusPreset\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42-Z+github.com/marginxio/marginx/x/oracle/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marginx.oracle.v1.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/oracle/types'
  _MARKETSTATUS._options = None
  _MARKETSTATUS._serialized_options = b'\210\243\036\000\250\244\036\001'
  _MARKETSTATUS.values_by_name["MARKET_STATUS_UNSPECIFIED"]._options = None
  _MARKETSTATUS.values_by_name["MARKET_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \021MarketStatusEmpty'
  _MARKETSTATUS.values_by_name["MARKET_STATUS_LISTED"]._options = None
  _MARKETSTATUS.values_by_name["MARKET_STATUS_LISTED"]._serialized_options = b'\212\235 \022MarketStatusListed'
  _MARKETSTATUS.values_by_name["MARKET_STATUS_SUSPEND"]._options = None
  _MARKETSTATUS.values_by_name["MARKET_STATUS_SUSPEND"]._serialized_options = b'\212\235 \023MarketStatusSuspend'
  _MARKETSTATUS.values_by_name["MARKET_STATUS_PRESET"]._options = None
  _MARKETSTATUS.values_by_name["MARKET_STATUS_PRESET"]._serialized_options = b'\212\235 \022MarketStatusPreset'
  _MARKET.fields_by_name['type']._options = None
  _MARKET.fields_by_name['type']._serialized_options = b'\310\336\037\001'
  _ANSWER.fields_by_name['answer']._options = None
  _ANSWER.fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _PRICE.fields_by_name['value']._options = None
  _PRICE.fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _AGGREGATOR.fields_by_name['config']._options = None
  _AGGREGATOR.fields_by_name['config']._serialized_options = b'\310\336\037\000'
  _AGGREGATOR.fields_by_name['submissions']._options = None
  _AGGREGATOR.fields_by_name['submissions']._serialized_options = b'\310\336\037\000'
  _AGGREGATOR.fields_by_name['type']._options = None
  _AGGREGATOR.fields_by_name['type']._serialized_options = b'\310\336\037\001'
  _globals['_MARKETSTATUS']._serialized_start=796
  _globals['_MARKETSTATUS']._serialized_end=1026
  _globals['_PARAMS']._serialized_start=101
  _globals['_PARAMS']._serialized_end=137
  _globals['_MARKET']._serialized_start=140
  _globals['_MARKET']._serialized_end=331
  _globals['_ANSWER']._serialized_start=333
  _globals['_ANSWER']._serialized_end=424
  _globals['_PRICE']._serialized_start=426
  _globals['_PRICE']._serialized_end=515
  _globals['_AGGREGATOR']._serialized_start=518
  _globals['_AGGREGATOR']._serialized_end=701
  _globals['_ORACLECONFIG']._serialized_start=703
  _globals['_ORACLECONFIG']._serialized_end=793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/migrate/v1/migrate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66x/migrate/v1/migrate.proto\x12\rfx.migrate.v1\"9\n\rMigrateRecord\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x42.Z,github.com/functionx/fx-core/x/migrate/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.migrate.v1.migrate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/functionx/fx-core/x/migrate/types'
  _globals['_MIGRATERECORD']._serialized_start=46
  _globals['_MIGRATERECORD']._serialized_end=103
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/match.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.fx.dex.v1 import order_pb2 as fx_dot_dex_dot_v1_dot_order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66x/dex/v1/match.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x15\x66x/dex/v1/order.proto\"\xe9\x01\n\tOrderFill\x12%\n\x05order\x18\x01 \x01(\x0b\x32\x10.fx.dex.v1.OrderB\x04\xc8\xde\x1f\x00\x12\x37\n\ndeal_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12<\n\x0fquantity_filled\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12>\n\x11quantity_unfilled\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"<\n\nOrderFills\x12.\n\norder_fill\x18\x01 \x03(\x0b\x32\x14.fx.dex.v1.OrderFillB\x04\xc8\xde\x1f\x00\";\n\x05Price\x12\x32\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"w\n\nOrderDepth\x12\x32\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x35\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"W\n\tOrderBook\x12$\n\x03\x62id\x18\x01 \x01(\x0b\x32\x11.fx.dex.v1.OrdersB\x04\xc8\xde\x1f\x00\x12$\n\x03\x61sk\x18\x02 \x01(\x0b\x32\x11.fx.dex.v1.OrdersB\x04\xc8\xde\x1f\x00\"\xba\x01\n\rDepthBookItem\x12\x32\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x39\n\x0c\x62uy_quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rsell_quantity\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\":\n\tDepthBook\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x18.fx.dex.v1.DepthBookItemB\x04\xc8\xde\x1f\x00\"\xbc\x01\n\x07Matcher\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12.\n\norder_book\x18\x02 \x01(\x0b\x32\x14.fx.dex.v1.OrderBookB\x04\xc8\xde\x1f\x00\x12<\n\x0flast_deal_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x32\n\x0c\x64\x65pth_curves\x18\x04 \x01(\x0b\x32\x16.fx.dex.v1.DepthCurvesB\x04\xc8\xde\x1f\x00\"\xab\x03\n\x0bMatchResult\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x11\n\tbid_count\x18\x02 \x01(\x03\x12\x11\n\task_count\x18\x03 \x01(\x03\x12\x37\n\ndeal_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12?\n\x12matched_bid_volume\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12?\n\x12matched_ask_volume\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12;\n\x0emax_bid_volume\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12;\n\x0emax_ask_volume\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x30\n\x0border_fills\x18\t \x01(\x0b\x32\x15.fx.dex.v1.OrderFillsB\x04\xc8\xde\x1f\x00\"B\n\x0cMatchResults\x12\x32\n\x0cmatch_result\x18\x01 \x03(\x0b\x32\x16.fx.dex.v1.MatchResultB\x04\xc8\xde\x1f\x00\"U\n\tDealPrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x37\n\ndeal_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"\xbb\x01\n\x0e\x44\x65pthCurveItem\x12\x32\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12:\n\rsell_quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x39\n\x0c\x62uy_quantity\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\"=\n\x0b\x44\x65pthCurves\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x19.fx.dex.v1.DepthCurveItemB\x04\xc8\xde\x1f\x00\x42-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.match_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _ORDERFILL.fields_by_name['order']._options = None
  _ORDERFILL.fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _ORDERFILL.fields_by_name['deal_price']._options = None
  _ORDERFILL.fields_by_name['deal_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERFILL.fields_by_name['quantity_filled']._options = None
  _ORDERFILL.fields_by_name['quantity_filled']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERFILL.fields_by_name['quantity_unfilled']._options = None
  _ORDERFILL.fields_by_name['quantity_unfilled']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERFILLS.fields_by_name['order_fill']._options = None
  _ORDERFILLS.fields_by_name['order_fill']._serialized_options = b'\310\336\037\000'
  _PRICE.fields_by_name['price']._options = None
  _PRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERDEPTH.fields_by_name['price']._options = None
  _ORDERDEPTH.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERDEPTH.fields_by_name['quantity']._options = None
  _ORDERDEPTH.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _ORDERBOOK.fields_by_name['bid']._options = None
  _ORDERBOOK.fields_by_name['bid']._serialized_options = b'\310\336\037\000'
  _ORDERBOOK.fields_by_name['ask']._options = None
  _ORDERBOOK.fields_by_name['ask']._serialized_options = b'\310\336\037\000'
  _DEPTHBOOKITEM.fields_by_name['price']._options = None
  _DEPTHBOOKITEM.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHBOOKITEM.fields_by_name['buy_quantity']._options = None
  _DEPTHBOOKITEM.fields_by_name['buy_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHBOOKITEM.fields_by_name['sell_quantity']._options = None
  _DEPTHBOOKITEM.fields_by_name['sell_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHBOOK.fields_by_name['items']._options = None
  _DEPTHBOOK.fields_by_name['items']._serialized_options = b'\310\336\037\000'
  _MATCHER.fields_by_name['order_book']._options = None
  _MATCHER.fields_by_name['order_book']._serialized_options = b'\310\336\037\000'
  _MATCHER.fields_by_name['last_deal_price']._options = None
  _MATCHER.fields_by_name['last_deal_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHER.fields_by_name['depth_curves']._options = None
  _MATCHER.fields_by_name['depth_curves']._serialized_options = b'\310\336\037\000'
  _MATCHRESULT.fields_by_name['deal_price']._options = None
  _MATCHRESULT.fields_by_name['deal_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHRESULT.fields_by_name['matched_bid_volume']._options = None
  _MATCHRESULT.fields_by_name['matched_bid_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHRESULT.fields_by_name['matched_ask_volume']._options = None
  _MATCHRESULT.fields_by_name['matched_ask_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHRESULT.fields_by_name['max_bid_volume']._options = None
  _MATCHRESULT.fields_by_name['max_bid_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHRESULT.fields_by_name['max_ask_volume']._options = None
  _MATCHRESULT.fields_by_name['max_ask_volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MATCHRESULT.fields_by_name['order_fills']._options = None
  _MATCHRESULT.fields_by_name['order_fills']._serialized_options = b'\310\336\037\000'
  _MATCHRESULTS.fields_by_name['match_result']._options = None
  _MATCHRESULTS.fields_by_name['match_result']._serialized_options = b'\310\336\037\000'
  _DEALPRICE.fields_by_name['deal_price']._options = None
  _DEALPRICE.fields_by_name['deal_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHCURVEITEM.fields_by_name['price']._options = None
  _DEPTHCURVEITEM.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHCURVEITEM.fields_by_name['sell_quantity']._options = None
  _DEPTHCURVEITEM.fields_by_name['sell_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHCURVEITEM.fields_by_name['buy_quantity']._options = None
  _DEPTHCURVEITEM.fields_by_name['buy_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _DEPTHCURVES.fields_by_name['items']._options = None
  _DEPTHCURVES.fields_by_name['items']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERFILL']._serialized_start=82
  _globals['_ORDERFILL']._serialized_end=315
  _globals['_ORDERFILLS']._serialized_start=317
  _globals['_ORDERFILLS']._serialized_end=377
  _globals['_PRICE']._serialized_start=379
  _globals['_PRICE']._serialized_end=438
  _globals['_ORDERDEPTH']._serialized_start=440
  _globals['_ORDERDEPTH']._serialized_end=559
  _globals['_ORDERBOOK']._serialized_start=561
  _globals['_ORDERBOOK']._serialized_end=648
  _globals['_DEPTHBOOKITEM']._serialized_start=651
  _globals['_DEPTHBOOKITEM']._serialized_end=837
  _globals['_DEPTHBOOK']._serialized_start=839
  _globals['_DEPTHBOOK']._serialized_end=897
  _globals['_MATCHER']._serialized_start=900
  _globals['_MATCHER']._serialized_end=1088
  _globals['_MATCHRESULT']._serialized_start=1091
  _globals['_MATCHRESULT']._serialized_end=1518
  _globals['_MATCHRESULTS']._serialized_start=1520
  _globals['_MATCHRESULTS']._serialized_end=1586
  _globals['_DEALPRICE']._serialized_start=1588
  _globals['_DEALPRICE']._serialized_end=1673
  _globals['_DEPTHCURVEITEM']._serialized_start=1676
  _globals['_DEPTHCURVEITEM']._serialized_end=1863
  _globals['_DEPTHCURVES']._serialized_start=1865
  _globals['_DEPTHCURVES']._serialized_end=1926
# @@protoc_insertion_point(module_scope)



import unittest

from fxsdk.msg import new_tx_from_base64
from fxsdk.x.cosmos.bank.v1beta1.tx_pb2 import MsgSend
from fxsdk.x.fx.dex.v1.order_pb2 import Direction


class TestProto(unittest.TestCase):
    def test_enum(self):
        buy = Direction.Name(Direction.BUY)
        self.assertEqual(str(buy), 'BUY')

    def test_parse_tx(self):
        raw_tx = 'CoYBCoMBChwvY29zbW9zLmJhbmsudjFiZXRhMS5Nc2dTZW5kEmMKKW14MTd3MGFkZWc2NGt5MGRheHdkMnVneXVuZWVsbG1qZ254cWV6dDk4EilteDE3dzBhZGVnNjRreTBkYXh3ZDJ1Z3l1bmVlbGxtamdueHFlenQ5OBoLCgRjdXNkEgMxMDASbwpZCk8KKC9ldGhlcm1pbnQuY3J5cHRvLnYxLmV0aHNlY3AyNTZrMS5QdWJLZXkSIwohA4MYU1tUEF1Keq5gwI/EX5aHGBtP38YlvRp1P6c5f+11EgQKAggBGAISEgoMCgRjdXNkEgQ0NTAwEKD3NhpBlC4qy88pAlxHfRoli+tOr4sgvKuWKOvp/OlD2iK38pgYKEVR0kF3ERbe1cDTnpEvb5Tfa/J3zGcyXYGm/OqRqQA='
        tx = new_tx_from_base64(raw_tx)
        self.assertEqual(len(tx.body.messages), 1)
        self.assertEqual(tx.body.messages[0].type_url, '/cosmos.bank.v1beta1.MsgSend')
        msg_send = MsgSend()
        msg_send.ParseFromString(tx.body.messages[0].value)
        self.assertEqual(msg_send.from_address, 'mx17w0adeg64ky0daxwd2ugyuneellmjgnxqezt98')
        self.assertEqual(msg_send.to_address, 'mx17w0adeg64ky0daxwd2ugyuneellmjgnxqezt98')
        self.assertEqual(len(msg_send.amount), 1)
        self.assertEqual(msg_send.amount[0].denom, 'cusd')
        self.assertEqual(msg_send.amount[0].amount, '100')
        print(tx)


if __name__ == '__main__':
    unittest.main()



import unittest

from fxsdk.client.marginx import MarginXClient

grpc_cli = MarginXClient('localhost:9090')

pair_id = 'btc:cusd'


class TestMxClientQuery(unittest.TestCase):

    def test_query_oracle_price(self):
        price = grpc_cli.query_oracle_price(pair_id)
        print(price)

    def test_query_oracle_prices(self):
        prices = grpc_cli.query_oracle_prices()
        print(prices)

    def test_query_oracle_market(self):
        market = grpc_cli.query_oracle_market(pair_id)
        print(market)

    def test_query_oracle_markets(self):
        markets = grpc_cli.query_oracle_markets()
        print(markets)


if __name__ == '__main__':
    unittest.main()



import base64
import time
import datetime

from google.protobuf.any_pb2 import Any
from decimal import Decimal

from fxsdk.dec import dec_to_str
from fxsdk.x.cosmos.bank.v1beta1.tx_pb2 import MsgSend
from fxsdk.x.cosmos.base.v1beta1.coin_pb2 import Coin
from fxsdk.x.cosmos.tx.v1beta1.tx_pb2 import Tx, TxRaw, TxBody, AuthInfo
from fxsdk.x.fx.dex.v1.order_pb2 import Direction
from fxsdk.x.fx.dex.v1.tx_pb2 import MsgCreateOrder, MsgCancelOrder, MsgClosePosition, MsgAddMargin
from fxsdk.x.ibc.applications.transfer.v1.tx_pb2 import MsgTransfer
from fxsdk.x.ibc.core.client.v1.client_pb2 import Height
from fxsdk.x.fx.ibc.applications.transfer.v1.tx_pb2 import MsgTransfer as FxMsgTransfer


def calculate_future_timestamp(seconds: int) -> int:
    dtime = datetime.datetime.now()
    ans_time = time.mktime(dtime.timetuple())
    ans_time = (int(ans_time) + seconds) * 1000 * 1000 * 1000
    return ans_time


def new_msg_send(from_address: str, to_address: str, amount: [Coin]) -> Any:
    msg = MsgSend(
        from_address=from_address,
        to_address=to_address,
        amount=amount,
    )
    msg_any = Any(
        type_url='/cosmos.bank.v1beta1.MsgSend',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_ibc_msg_transfer(channel: str, sender: str, receiver: str, token: Coin, memo: str = '') -> Any:
    msg = MsgTransfer(
        source_port="transfer",
        source_channel=channel,
        token=token,
        sender=sender,
        receiver=receiver,
        timeout_height=Height(revision_number=0, revision_height=0),
        timeout_timestamp=calculate_future_timestamp(60 * 60),  # 1 hour
        memo=memo,
    )
    msg_any = Any(
        type_url='/ibc.applications.transfer.v1.MsgTransfer',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_ibc_fx_msg_transfer(channel: str, sender: str, receiver: str, token: Coin, router: str, fee: Coin,
                            memo: str = '') -> Any:
    if token.denom != fee.denom:
        raise Exception("token denom must equal to fee denom")
    msg = FxMsgTransfer(
        source_port="transfer",
        source_channel=channel,
        token=token,
        sender=sender,
        receiver=receiver,
        timeout_height=Height(revision_number=0, revision_height=0),
        timeout_timestamp=calculate_future_timestamp(60 * 60),  # 1 hour
        router=router,
        fee=fee,
        memo=memo,
    )
    msg_any = Any(
        type_url='/fx.ibc.applications.transfer.v1.MsgTransfer',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_msg_create_order(owner: str, pair_id: str, direction: Direction, price: Decimal, base_quantity: Decimal,
                         leverage: int) -> Any:
    msg = MsgCreateOrder(
        owner=owner,
        pair_id=pair_id,
        direction=direction,
        price=dec_to_str(price),
        base_quantity=dec_to_str(base_quantity),
        leverage=leverage,
    )
    msg_any = Any(
        type_url='/fx.dex.v1.MsgCreateOrder',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_msg_cancel_order(owner: str, order_id: str) -> Any:
    msg = MsgCancelOrder(owner=owner, order_id=order_id)
    msg_any = Any(
        type_url='/fx.dex.v1.MsgCancelOrder',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_msg_close_position(owner: str, pair_id: str, position_id: str, price: Decimal, base_quantity: Decimal,
                           full_close: bool, market_close=False):
    msg = MsgClosePosition(
        owner=owner,
        pair_id=pair_id,
        position_id=position_id,
        price=dec_to_str(price),
        base_quantity=dec_to_str(base_quantity),
        full_close=full_close,
        market_close=market_close,
    )
    msg_any = Any(
        type_url='/fx.dex.v1.MsgClosePosition',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_msg_add_margin(owner: str, pair_id: str, position_id: str, amount: Decimal):
    msg = MsgAddMargin(
        owner=owner,
        pair_id=pair_id,
        position_id=position_id,
        margin=dec_to_str(amount),
    )
    msg_any = Any(
        type_url='/fx.dex.v1.MsgAddMargin',
        value=msg.SerializeToString(),
    )
    return msg_any


def new_tx_from_base64(base64_tx: str) -> Tx:
    tx_raw = TxRaw()
    tx_raw.ParseFromString(base64.b64decode(base64_tx))
    tx_body = TxBody()
    tx_body.ParseFromString(tx_raw.body_bytes)
    auth_info = AuthInfo()
    auth_info.ParseFromString(tx_raw.auth_info_bytes)
    return Tx(
        body=tx_body,
        auth_info=auth_info,
        signatures=tx_raw.signatures
    )



import asyncio
import itertools
from urllib.parse import urlparse
from typing import Callable, Awaitable, Optional, Dict

from fxsdk.client.http import RpcRequest, HttpRpcClient
from fxsdk.websockets import ReconnectingWebsocket, WebsocketManagerBase
from fxsdk.x.cosmos.tx.v1beta1.service_pb2 import BroadcastMode, BROADCAST_MODE_SYNC, BROADCAST_MODE_ASYNC, \
    BROADCAST_MODE_BLOCK
from fxsdk.x.cosmos.tx.v1beta1.tx_pb2 import Tx, TxRaw


class WebsocketException(Exception):
    pass


class ReconnectingRpcWebsocket(ReconnectingWebsocket):
    id_generator = itertools.count(1)

    def _get_ws_endpoint_url(self):
        o = urlparse(self._endpoint_url)
        if o.scheme == 'http' or o.scheme == 'tcp':
            return f"ws://{o.netloc}/websocket"
        elif o.scheme == 'https':
            return f"wss://{o.netloc}/websocket"
        return f"{self._endpoint_url}/websocket"

    async def send_keepalive(self):
        await self.send_rpc_message('keepAlive')

    async def send_rpc_message(self, method, params=None, retry_count=0):
        if not self._socket:
            if retry_count < self._retry_count:
                await asyncio.sleep(1)
                await self.send_rpc_message(method, params, retry_count + 1)
            else:
                raise WebsocketException("Unable to send, not connected")
        else:
            req = RpcRequest(method, next(self.id_generator), params)
            await self._socket.send(str(req))

    async def ping(self):
        await self.send_rpc_message('ping')


class WebsocketRpcClient(WebsocketManagerBase):
    __doc__ = HttpRpcClient.__doc__

    @classmethod
    async def create(cls, endpoint_url: str, loop, callback: Callable[[Dict], Awaitable[None]] = None):
        self = WebsocketRpcClient()
        loop = loop if loop else asyncio.get_event_loop()
        callback = callback if callback else self.receive
        self._conn = ReconnectingRpcWebsocket(endpoint_url, loop=loop, recv=callback)
        return self

    async def close(self):
        try:
            await self.unsubscribe_all()
            await self._conn.cancel()
        except WebsocketException:
            pass

    async def subscribe(self, query):
        req_msg = {
            "query": query
        }
        await self._conn.send_rpc_message('subscribe', req_msg)

    async def unsubscribe(self, query):
        req_msg = {
            "query": query
        }
        await self._conn.send_rpc_message('unsubscribe', req_msg)

    async def unsubscribe_all(self):
        await self._conn.send_rpc_message('unsubscribe_all')

    async def get_abci_info(self):
        await self._conn.send_rpc_message('abci_info')

    async def get_consensus_state(self):
        await self._conn.send_rpc_message('consensus_state')

    async def dump_consensus_state(self):
        await self._conn.send_rpc_message('dump_consensus_state')

    async def get_genesis(self):
        await self._conn.send_rpc_message('genesis')

    async def get_net_info(self):
        await self._conn.send_rpc_message('net_info')

    async def get_num_unconfirmed_txs(self):
        await self._conn.send_rpc_message('num_unconfirmed_txs')

    async def get_status(self):
        await self._conn.send_rpc_message('status')

    async def get_health(self):
        await self._conn.send_rpc_message('health')

    async def get_unconfirmed_txs(self):
        await self._conn.send_rpc_message('unconfirmed_txs')

    async def get_validators(self, height: int, page: int = 1):
        data = {
            'height': str(height),
            'page': str(page),
            'per_page': '30'
        }
        await self._conn.send_rpc_message('validators', data)

    async def abci_query(self, data: str, path: Optional[str] = None,
                         prove: Optional[bool] = None, height: Optional[int] = None):
        data = {
            'data': data
        }
        if path:
            data['path'] = path
        if prove:
            data['prove'] = str(prove)
        if height:
            data['height'] = str(height)

        await self._conn.send_rpc_message('abci_query', data)

    async def get_block_header(self, height: Optional[int] = None):
        data = {
            'height': str(height) if height else None
        }
        await self._conn.send_rpc_message('block_header', data)

    async def get_block(self, height: Optional[int] = None):
        data = {
            'height': str(height) if height else None
        }
        await self._conn.send_rpc_message('block', data)

    async def block_search(self, query: str, prove: Optional[bool] = None,
                           page: Optional[int] = None, per_page: Optional[int] = None,
                           order_by: Optional[str] = None):
        data = {
            'query': query
        }
        if prove:
            data['prove'] = str(prove)
        if page:
            data['page'] = str(page)
        if per_page:
            data['per_page'] = str(per_page)
        if order_by:
            data['order_by'] = order_by

        await self._conn.send_rpc_message('block_search', data)

    async def get_block_results(self, height: int):
        data = {
            'height': str(height)
        }
        await self._conn.send_rpc_message('block_results', data)

    async def get_block_commit(self, height: int):
        data = {
            'height': str(height)
        }
        await self._conn.send_rpc_message('commit', data)

    async def get_blockchain_info(self, min_height: int, max_height: int):
        assert max_height > min_height

        data = {
            'minHeight': str(min_height),
            'maxHeight': str(max_height)
        }
        await self._conn.send_rpc_message('blockchain', data)

    async def check_tx(self, tx: Tx):
        tx_raw = TxRaw(
            body_bytes=tx.body.SerializeToString(),
            auth_info_bytes=tx.auth_info.SerializeToString(),
            signatures=tx.signatures,
        )
        tx_bytes = tx_raw.SerializeToString()
        data = {
            'tx': '0x' + tx_bytes.hex(),
        }
        await self._conn.send_rpc_message('check_tx', data)

    async def broadcast_tx(self, tx: Tx, mode: BroadcastMode = BROADCAST_MODE_SYNC):
        tx_raw = TxRaw(
            body_bytes=tx.body.SerializeToString(),
            auth_info_bytes=tx.auth_info.SerializeToString(),
            signatures=tx.signatures,
        )
        tx_bytes = tx_raw.SerializeToString()
        data = {
            'tx': '0x' + tx_bytes.hex(),
        }
        if mode == BROADCAST_MODE_SYNC:
            return await self._broadcast_tx_sync(data)
        elif mode == BROADCAST_MODE_ASYNC:
            return await self._broadcast_tx_async(data)
        elif mode == BROADCAST_MODE_BLOCK:
            return await self._broadcast_tx_commit(data)

    async def _broadcast_tx_async(self, tx_data: Dict):
        await self._conn.send_rpc_message('broadcast_tx_async', tx_data)

    async def _broadcast_tx_commit(self, tx_data: Dict):
        await self._conn.send_rpc_message('broadcast_tx_commit', tx_data)

    async def _broadcast_tx_sync(self, tx_data: Dict):
        await self._conn.send_rpc_message('broadcast_tx_sync', tx_data)

    async def get_consensus_params(self, height: Optional[int] = None):
        data = {
            'height': str(height) if height else None
        }
        await self._conn.send_rpc_message('consensus_params', data)

    async def get_tx(self, tx_hash: str, prove: Optional[bool] = None):
        data = {
            'hash': tx_hash
        }
        if prove:
            data['prove'] = str(prove)

        await self._conn.send_rpc_message('tx', data)

    async def tx_search(self, query: str, prove: Optional[bool] = None,
                        page: Optional[int] = None, per_page: Optional[int] = None,
                        order_by: Optional[str] = None):
        data = {
            'query': query
        }
        if prove:
            data['prove'] = str(prove)
        if page:
            data['page'] = str(page)
        if per_page:
            data['per_page'] = str(per_page)
        if order_by:
            data['order_by'] = order_by

        await self._conn.send_rpc_message('tx_search', data)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethermint/evm/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from fxsdk.x.ethermint.evm.v1 import evm_pb2 as ethermint_dot_evm_dot_v1_dot_evm__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65thermint/evm/v1/tx.proto\x12\x10\x65thermint.evm.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1a\x65thermint/evm/v1/evm.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\"w\n\rMsgEthereumTx\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x13\n\x04size\x18\x02 \x01(\x01\x42\x05\xea\xde\x1f\x01-\x12\x19\n\x04hash\x18\x03 \x01(\tB\x0b\xf2\xde\x1f\x07rlp:\"-\"\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t:\x04\x88\xa0\x1f\x00\"\x83\x02\n\x08LegacyTx\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12=\n\tgas_price\x18\x02 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x19\n\x03gas\x18\x03 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimit\x12\n\n\x02to\x18\x04 \x01(\t\x12\x43\n\x05value\x18\x05 \x01(\tB4\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x06\x41mount\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\t\n\x01v\x18\x07 \x01(\x0c\x12\t\n\x01r\x18\x08 \x01(\x0c\x12\t\n\x01s\x18\t \x01(\x0c:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\xae\x03\n\x0c\x41\x63\x63\x65ssListTx\x12R\n\x08\x63hain_id\x18\x01 \x01(\tB@\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x07\x43hainID\xea\xde\x1f\x07\x63hainID\x12\r\n\x05nonce\x18\x02 \x01(\x04\x12=\n\tgas_price\x18\x03 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x19\n\x03gas\x18\x04 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimit\x12\n\n\x02to\x18\x05 \x01(\t\x12\x43\n\x05value\x18\x06 \x01(\tB4\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x06\x41mount\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\x0c\x12Q\n\x08\x61\x63\x63\x65sses\x18\x08 \x03(\x0b\x32\x1d.ethermint.evm.v1.AccessTupleB \xc8\xde\x1f\x00\xea\xde\x1f\naccessList\xaa\xdf\x1f\nAccessList\x12\t\n\x01v\x18\t \x01(\x0c\x12\t\n\x01r\x18\n \x01(\x0c\x12\t\n\x01s\x18\x0b \x01(\x0c:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\xf1\x03\n\x0c\x44ynamicFeeTx\x12R\n\x08\x63hain_id\x18\x01 \x01(\tB@\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x07\x43hainID\xea\xde\x1f\x07\x63hainID\x12\r\n\x05nonce\x18\x02 \x01(\x04\x12?\n\x0bgas_tip_cap\x18\x03 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12?\n\x0bgas_fee_cap\x18\x04 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x19\n\x03gas\x18\x05 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimit\x12\n\n\x02to\x18\x06 \x01(\t\x12\x43\n\x05value\x18\x07 \x01(\tB4\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xe2\xde\x1f\x06\x41mount\x12\x0c\n\x04\x64\x61ta\x18\x08 \x01(\x0c\x12Q\n\x08\x61\x63\x63\x65sses\x18\t \x03(\x0b\x32\x1d.ethermint.evm.v1.AccessTupleB \xc8\xde\x1f\x00\xea\xde\x1f\naccessList\xaa\xdf\x1f\nAccessList\x12\t\n\x01v\x18\n \x01(\x0c\x12\t\n\x01r\x18\x0b \x01(\x0c\x12\t\n\x01s\x18\x0c \x01(\x0c:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\"\n\x1a\x45xtensionOptionsEthereumTx:\x04\x88\xa0\x1f\x00\"\x81\x01\n\x15MsgEthereumTxResponse\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12#\n\x04logs\x18\x02 \x03(\x0b\x32\x15.ethermint.evm.v1.Log\x12\x0b\n\x03ret\x18\x03 \x01(\x0c\x12\x10\n\x08vm_error\x18\x04 \x01(\t\x12\x10\n\x08gas_used\x18\x05 \x01(\x04:\x04\x88\xa0\x1f\x00\x32\x84\x01\n\x03Msg\x12}\n\nEthereumTx\x12\x1f.ethermint.evm.v1.MsgEthereumTx\x1a\'.ethermint.evm.v1.MsgEthereumTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/ethermint/evm/v1/ethereum_txB(Z&github.com/evmos/ethermint/x/evm/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ethermint.evm.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/evmos/ethermint/x/evm/types'
  _MSGETHEREUMTX.fields_by_name['size']._options = None
  _MSGETHEREUMTX.fields_by_name['size']._serialized_options = b'\352\336\037\001-'
  _MSGETHEREUMTX.fields_by_name['hash']._options = None
  _MSGETHEREUMTX.fields_by_name['hash']._serialized_options = b'\362\336\037\007rlp:\"-\"'
  _MSGETHEREUMTX._options = None
  _MSGETHEREUMTX._serialized_options = b'\210\240\037\000'
  _LEGACYTX.fields_by_name['gas_price']._options = None
  _LEGACYTX.fields_by_name['gas_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _LEGACYTX.fields_by_name['gas']._options = None
  _LEGACYTX.fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _LEGACYTX.fields_by_name['value']._options = None
  _LEGACYTX.fields_by_name['value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\006Amount'
  _LEGACYTX._options = None
  _LEGACYTX._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _ACCESSLISTTX.fields_by_name['chain_id']._options = None
  _ACCESSLISTTX.fields_by_name['chain_id']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\007ChainID\352\336\037\007chainID'
  _ACCESSLISTTX.fields_by_name['gas_price']._options = None
  _ACCESSLISTTX.fields_by_name['gas_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _ACCESSLISTTX.fields_by_name['gas']._options = None
  _ACCESSLISTTX.fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _ACCESSLISTTX.fields_by_name['value']._options = None
  _ACCESSLISTTX.fields_by_name['value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\006Amount'
  _ACCESSLISTTX.fields_by_name['accesses']._options = None
  _ACCESSLISTTX.fields_by_name['accesses']._serialized_options = b'\310\336\037\000\352\336\037\naccessList\252\337\037\nAccessList'
  _ACCESSLISTTX._options = None
  _ACCESSLISTTX._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _DYNAMICFEETX.fields_by_name['chain_id']._options = None
  _DYNAMICFEETX.fields_by_name['chain_id']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\007ChainID\352\336\037\007chainID'
  _DYNAMICFEETX.fields_by_name['gas_tip_cap']._options = None
  _DYNAMICFEETX.fields_by_name['gas_tip_cap']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _DYNAMICFEETX.fields_by_name['gas_fee_cap']._options = None
  _DYNAMICFEETX.fields_by_name['gas_fee_cap']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _DYNAMICFEETX.fields_by_name['gas']._options = None
  _DYNAMICFEETX.fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _DYNAMICFEETX.fields_by_name['value']._options = None
  _DYNAMICFEETX.fields_by_name['value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\342\336\037\006Amount'
  _DYNAMICFEETX.fields_by_name['accesses']._options = None
  _DYNAMICFEETX.fields_by_name['accesses']._serialized_options = b'\310\336\037\000\352\336\037\naccessList\252\337\037\nAccessList'
  _DYNAMICFEETX._options = None
  _DYNAMICFEETX._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _EXTENSIONOPTIONSETHEREUMTX._options = None
  _EXTENSIONOPTIONSETHEREUMTX._serialized_options = b'\210\240\037\000'
  _MSGETHEREUMTXRESPONSE._options = None
  _MSGETHEREUMTXRESPONSE._serialized_options = b'\210\240\037\000'
  _MSG.methods_by_name['EthereumTx']._options = None
  _MSG.methods_by_name['EthereumTx']._serialized_options = b'\202\323\344\223\002\037\"\035/ethermint/evm/v1/ethereum_tx'
  _globals['_MSGETHEREUMTX']._serialized_start=181
  _globals['_MSGETHEREUMTX']._serialized_end=300
  _globals['_LEGACYTX']._serialized_start=303
  _globals['_LEGACYTX']._serialized_end=562
  _globals['_ACCESSLISTTX']._serialized_start=565
  _globals['_ACCESSLISTTX']._serialized_end=995
  _globals['_DYNAMICFEETX']._serialized_start=998
  _globals['_DYNAMICFEETX']._serialized_end=1495
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._serialized_start=1497
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._serialized_end=1531
  _globals['_MSGETHEREUMTXRESPONSE']._serialized_start=1534
  _globals['_MSGETHEREUMTXRESPONSE']._serialized_end=1663
  _globals['_MSG']._serialized_start=1666
  _globals['_MSG']._serialized_end=1798
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/dex/v1/margin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66x/dex/v1/margin.proto\x12\tfx.dex.v1\x1a\x14gogoproto/gogo.proto\"\xfc\x02\n\x0fMarginRateTable\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x10\n\x08leverage\x18\x02 \x01(\x04\x12=\n\x10nominal_position\x18\x03 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12>\n\x11maint_margin_rate\x18\x04 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x39\n\x0cmaint_amount\x18\x05 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x11\n\tLeverages\x18\x06 \x03(\r\x12\x32\n\x05Rates\x18\x07 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\x12\x45\n\x18impact_price_base_amount\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecB-Z+github.com/marginxio/marginx/x/dex/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.dex.v1.margin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/dex/v1/types'
  _MARGINRATETABLE.fields_by_name['nominal_position']._options = None
  _MARGINRATETABLE.fields_by_name['nominal_position']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MARGINRATETABLE.fields_by_name['maint_margin_rate']._options = None
  _MARGINRATETABLE.fields_by_name['maint_margin_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MARGINRATETABLE.fields_by_name['maint_amount']._options = None
  _MARGINRATETABLE.fields_by_name['maint_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MARGINRATETABLE.fields_by_name['Rates']._options = None
  _MARGINRATETABLE.fields_by_name['Rates']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _MARGINRATETABLE.fields_by_name['impact_price_base_amount']._options = None
  _MARGINRATETABLE.fields_by_name['impact_price_base_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MARGINRATETABLE']._serialized_start=60
  _globals['_MARGINRATETABLE']._serialized_end=440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/crosschain/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66x/crosschain/v1/types.proto\x12\x18\x66x.gravity.crosschain.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"!\n\x0eProposalOracle\x12\x0f\n\x07oracles\x18\x01 \x03(\t\"\xf3\x01\n\x06Oracle\x12\x16\n\x0eoracle_address\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridger_address\x18\x02 \x01(\t\x12\x18\n\x10\x65xternal_address\x18\x03 \x01(\t\x12G\n\x0f\x64\x65legate_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x14\n\x0cstart_height\x18\x05 \x01(\x03\x12\x0e\n\x06online\x18\x06 \x01(\x08\x12\x1a\n\x12\x64\x65legate_validator\x18\x07 \x01(\t\x12\x13\n\x0bslash_times\x18\x08 \x01(\x03\":\n\x0f\x42ridgeValidator\x12\r\n\x05power\x18\x01 \x01(\x04\x12\x18\n\x10\x65xternal_address\x18\x02 \x01(\t\"l\n\tOracleSet\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12@\n\x07members\x18\x02 \x03(\x0b\x32).fx.gravity.crosschain.v1.BridgeValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x04\"N\n\x17LastObservedBlockHeight\x12\x1d\n\x15\x65xternal_block_height\x18\x01 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\x04\"@\n\x0b\x42ridgeToken\x12\r\n\x05token\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x13\n\x0b\x63hannel_ibc\x18\x03 \x01(\t\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xbc\x01\n\x0fOutgoingTxBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x02 \x01(\x04\x12\x42\n\x0ctransactions\x18\x03 \x03(\x0b\x32,.fx.gravity.crosschain.v1.OutgoingTransferTx\x12\x16\n\x0etoken_contract\x18\x04 \x01(\t\x12\r\n\x05\x62lock\x18\x05 \x01(\x04\x12\x12\n\nfeeReceive\x18\x06 \x01(\t\"\xba\x01\n\x12OutgoingTransferTx\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65st_address\x18\x03 \x01(\t\x12\x39\n\x05token\x18\x04 \x01(\x0b\x32$.fx.gravity.crosschain.v1.ERC20TokenB\x04\xc8\xde\x1f\x00\x12\x37\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32$.fx.gravity.crosschain.v1.ERC20TokenB\x04\xc8\xde\x1f\x00\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\x14\n\x05IDSet\x12\x0b\n\x03ids\x18\x01 \x03(\x04\"\xc0\x01\n\tBatchFees\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12\x42\n\ntotal_fees\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\x12\x11\n\ttotal_txs\x18\x03 \x01(\x04\x12\x44\n\x0ctotal_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"f\n\x0bMinBatchFee\x12\x16\n\x0etoken_contract\x18\x01 \x01(\t\x12?\n\x07\x62\x61seFee\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\"\xd6\x03\n\x06Params\x12\x12\n\ngravity_id\x18\x01 \x01(\t\x12\x1a\n\x12\x61verage_block_time\x18\x02 \x01(\x04\x12\x1e\n\x16\x65xternal_batch_timeout\x18\x03 \x01(\x04\x12#\n\x1b\x61verage_external_block_time\x18\x04 \x01(\x04\x12\x15\n\rsigned_window\x18\x05 \x01(\x04\x12\x46\n\x0eslash_fraction\x18\x06 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12^\n&oracle_set_update_power_change_percent\x18\x07 \x01(\x0c\x42.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12#\n\x1bibc_transfer_timeout_height\x18\x08 \x01(\x04\x12\x15\n\x07oracles\x18\t \x03(\tB\x04\xc8\xde\x1f\x01\x12;\n\x12\x64\x65legate_threshold\x18\n \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x19\n\x11\x64\x65legate_multiple\x18\x0b \x01(\x03:\x04\x80\xdc \x00\"\x96\x01\n\x1cInitCrossChainParamsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x30\n\x06params\x18\x03 \x01(\x0b\x32 .fx.gravity.crosschain.v1.Params\x12\x12\n\nchain_name\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"s\n\x1aUpdateChainOraclesProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07oracles\x18\x03 \x03(\t\x12\x12\n\nchain_name\x18\x04 \x01(\t:\x0c\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00*\xa9\x01\n\tClaimType\x12\x1a\n\x16\x43LAIM_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43LAIM_TYPE_SEND_TO_FX\x10\x01\x12\x1f\n\x1b\x43LAIM_TYPE_SEND_TO_EXTERNAL\x10\x02\x12\x1b\n\x17\x43LAIM_TYPE_BRIDGE_TOKEN\x10\x03\x12!\n\x1d\x43LAIM_TYPE_ORACLE_SET_UPDATED\x10\x04\x1a\x04\x88\xa3\x1e\x00\x42\x31Z/github.com/functionx/fx-core/x/crosschain/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.crosschain.v1.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/functionx/fx-core/x/crosschain/types'
  _CLAIMTYPE._options = None
  _CLAIMTYPE._serialized_options = b'\210\243\036\000'
  _ORACLE.fields_by_name['delegate_amount']._options = None
  _ORACLE.fields_by_name['delegate_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _ORACLESET.fields_by_name['members']._options = None
  _ORACLESET.fields_by_name['members']._serialized_options = b'\310\336\037\000'
  _OUTGOINGTRANSFERTX.fields_by_name['token']._options = None
  _OUTGOINGTRANSFERTX.fields_by_name['token']._serialized_options = b'\310\336\037\000'
  _OUTGOINGTRANSFERTX.fields_by_name['fee']._options = None
  _OUTGOINGTRANSFERTX.fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _ERC20TOKEN.fields_by_name['amount']._options = None
  _ERC20TOKEN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_fees']._options = None
  _BATCHFEES.fields_by_name['total_fees']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _BATCHFEES.fields_by_name['total_amount']._options = None
  _BATCHFEES.fields_by_name['total_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _MINBATCHFEE.fields_by_name['baseFee']._options = None
  _MINBATCHFEE.fields_by_name['baseFee']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int'
  _PARAMS.fields_by_name['slash_fraction']._options = None
  _PARAMS.fields_by_name['slash_fraction']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PARAMS.fields_by_name['oracle_set_update_power_change_percent']._options = None
  _PARAMS.fields_by_name['oracle_set_update_power_change_percent']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PARAMS.fields_by_name['oracles']._options = None
  _PARAMS.fields_by_name['oracles']._serialized_options = b'\310\336\037\001'
  _PARAMS.fields_by_name['delegate_threshold']._options = None
  _PARAMS.fields_by_name['delegate_threshold']._serialized_options = b'\310\336\037\000'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\200\334 \000'
  _INITCROSSCHAINPARAMSPROPOSAL._options = None
  _INITCROSSCHAINPARAMSPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _UPDATECHAINORACLESPROPOSAL._options = None
  _UPDATECHAINORACLESPROPOSAL._serialized_options = b'\210\240\037\000\230\240\037\000\350\240\037\000'
  _globals['_CLAIMTYPE']._serialized_start=2378
  _globals['_CLAIMTYPE']._serialized_end=2547
  _globals['_PROPOSALORACLE']._serialized_start=139
  _globals['_PROPOSALORACLE']._serialized_end=172
  _globals['_ORACLE']._serialized_start=175
  _globals['_ORACLE']._serialized_end=418
  _globals['_BRIDGEVALIDATOR']._serialized_start=420
  _globals['_BRIDGEVALIDATOR']._serialized_end=478
  _globals['_ORACLESET']._serialized_start=480
  _globals['_ORACLESET']._serialized_end=588
  _globals['_LASTOBSERVEDBLOCKHEIGHT']._serialized_start=590
  _globals['_LASTOBSERVEDBLOCKHEIGHT']._serialized_end=668
  _globals['_BRIDGETOKEN']._serialized_start=670
  _globals['_BRIDGETOKEN']._serialized_end=734
  _globals['_ATTESTATION']._serialized_start=736
  _globals['_ATTESTATION']._serialized_end=835
  _globals['_OUTGOINGTXBATCH']._serialized_start=838
  _globals['_OUTGOINGTXBATCH']._serialized_end=1026
  _globals['_OUTGOINGTRANSFERTX']._serialized_start=1029
  _globals['_OUTGOINGTRANSFERTX']._serialized_end=1215
  _globals['_ERC20TOKEN']._serialized_start=1217
  _globals['_ERC20TOKEN']._serialized_end=1311
  _globals['_IDSET']._serialized_start=1313
  _globals['_IDSET']._serialized_end=1333
  _globals['_BATCHFEES']._serialized_start=1336
  _globals['_BATCHFEES']._serialized_end=1528
  _globals['_MINBATCHFEE']._serialized_start=1530
  _globals['_MINBATCHFEE']._serialized_end=1632
  _globals['_PARAMS']._serialized_start=1635
  _globals['_PARAMS']._serialized_end=2105
  _globals['_INITCROSSCHAINPARAMSPROPOSAL']._serialized_start=2108
  _globals['_INITCROSSCHAINPARAMSPROPOSAL']._serialized_end=2258
  _globals['_UPDATECHAINORACLESPROPOSAL']._serialized_start=2260
  _globals['_UPDATECHAINORACLESPROPOSAL']._serialized_end=2375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fx/ibc/applications/transfer/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fxsdk.x.ibc.applications.transfer.v1 import query_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+fx/ibc/applications/transfer/v1/query.proto\x12\x1f\x66x.ibc.applications.transfer.v1\x1a(ibc/applications/transfer/v1/query.proto2\xf6\x04\n\x05Query\x12{\n\nDenomTrace\x12\x34.ibc.applications.transfer.v1.QueryDenomTraceRequest\x1a\x35.ibc.applications.transfer.v1.QueryDenomTraceResponse\"\x00\x12~\n\x0b\x44\x65nomTraces\x12\x35.ibc.applications.transfer.v1.QueryDenomTracesRequest\x1a\x36.ibc.applications.transfer.v1.QueryDenomTracesResponse\"\x00\x12o\n\x06Params\x12\x30.ibc.applications.transfer.v1.QueryParamsRequest\x1a\x31.ibc.applications.transfer.v1.QueryParamsResponse\"\x00\x12x\n\tDenomHash\x12\x33.ibc.applications.transfer.v1.QueryDenomHashRequest\x1a\x34.ibc.applications.transfer.v1.QueryDenomHashResponse\"\x00\x12\x84\x01\n\rEscrowAddress\x12\x37.ibc.applications.transfer.v1.QueryEscrowAddressRequest\x1a\x38.ibc.applications.transfer.v1.QueryEscrowAddressResponse\"\x00\x42@Z>github.com/functionx/fx-core/x/ibc/applications/transfer/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fx.ibc.applications.transfer.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z>github.com/functionx/fx-core/x/ibc/applications/transfer/types'
  _globals['_QUERY']._serialized_start=123
  _globals['_QUERY']._serialized_end=753
# @@protoc_insertion_point(module_scope)



import time
import grpc

from google.protobuf.any_pb2 import Any
from urllib.parse import urlparse
from typing import Optional

from fxsdk.msg import new_msg_send
from fxsdk.wallet.builder import TxBuilder
from fxsdk.coin import parse_coins

from fxsdk.x.cosmos.auth.v1beta1.auth_pb2 import BaseAccount, ModuleAccount
from fxsdk.x.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest, Bech32PrefixRequest, QueryModuleAccountsRequest
from fxsdk.x.cosmos.auth.v1beta1.query_pb2_grpc import QueryStub as AuthClient
from fxsdk.x.cosmos.bank.v1beta1.bank_pb2 import Supply
from fxsdk.x.cosmos.bank.v1beta1.query_pb2 import (QueryBalanceRequest, QueryAllBalancesRequest,
                                                   QueryTotalSupplyRequest, QuerySupplyOfRequest)
from fxsdk.x.cosmos.bank.v1beta1.query_pb2_grpc import QueryStub as BankClient
from fxsdk.x.cosmos.base.abci.v1beta1.abci_pb2 import GasInfo, TxResponse
from fxsdk.x.cosmos.base.tendermint.v1beta1.query_pb2 import GetBlockByHeightRequest, GetLatestBlockRequest, \
    GetSyncingRequest, GetNodeInfoRequest
from fxsdk.x.cosmos.base.tendermint.v1beta1.query_pb2_grpc import ServiceStub as TendermintClient
from fxsdk.x.cosmos.base.v1beta1.coin_pb2 import Coin
from fxsdk.x.cosmos.staking.v1beta1.query_pb2 import QueryValidatorsRequest
from fxsdk.x.cosmos.staking.v1beta1.query_pb2 import QueryParamsRequest as QueryStakingParamsRequest
from fxsdk.x.cosmos.staking.v1beta1.query_pb2_grpc import QueryStub as StakingClient
from fxsdk.x.cosmos.staking.v1beta1.staking_pb2 import Validator
from fxsdk.x.cosmos.staking.v1beta1.staking_pb2 import Params as StakingParams
from fxsdk.x.cosmos.tx.v1beta1.service_pb2 import BROADCAST_MODE_SYNC, BroadcastMode, BroadcastTxRequest, \
    SimulateRequest, \
    GetTxRequest, GetTxResponse, OrderBy, GetTxsEventRequest, GetTxsEventResponse
from fxsdk.x.cosmos.tx.v1beta1.service_pb2_grpc import ServiceStub as TxClient
from fxsdk.x.cosmos.tx.v1beta1.tx_pb2 import Fee, Tx, TxRaw
from fxsdk.x.cosmos.base.node.v1beta1.query_pb2_grpc import ServiceStub as CosmosNodeClient
from fxsdk.x.cosmos.base.node.v1beta1.query_pb2 import ConfigRequest
from fxsdk.x.tendermint.p2p.types_pb2 import DefaultNodeInfo
from fxsdk.x.tendermint.types.block_pb2 import Block

GRPCBlockHeightHeader = 'x-cosmos-block-height'
DefGasLimit = 200_000
DefGasAdjustment = 1.5


class Client:
    def __init__(self, url: str = 'localhost:9090'):
        if urlparse(url).scheme == "https":
            self.channel = grpc.secure_channel(
                urlparse(url).netloc, grpc.ssl_channel_credentials())
        else:
            self.channel = grpc.insecure_channel(url)

    def query_account_info(self, address: str, height: Optional[int] = 0) -> BaseAccount:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = AuthClient(self.channel).Account(QueryAccountRequest(address=address), metadata=metadata)
        account_any = response.account
        account = BaseAccount()
        if account_any.Is(account.DESCRIPTOR):
            account_any.Unpack(account)
            return account

    def query_bech32_prefix(self) -> str:
        response = AuthClient(self.channel).Bech32Prefix(Bech32PrefixRequest())
        return response.bech32_prefix

    def query_module_accounts(self) -> [ModuleAccount]:
        response = AuthClient(self.channel).ModuleAccounts(QueryModuleAccountsRequest())
        accounts = []
        for account_any in response.accounts:
            account = ModuleAccount()
            account_any.Unpack(account)
            accounts.append(account)
        return accounts

    def query_all_balances(self, address: str, height: Optional[int] = 0) -> [Coin]:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = BankClient(self.channel).AllBalances(QueryAllBalancesRequest(address=address), metadata=metadata)
        return response.balances

    def query_balance(self, address: str, denom: str, height: Optional[int] = 0) -> Coin:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = BankClient(self.channel).Balance(QueryBalanceRequest(address=address, denom=denom),
                                                    metadata=metadata)
        return response.balance

    def query_total_supply(self, height: Optional[int] = 0) -> [Supply]:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = BankClient(self.channel).TotalSupply(QueryTotalSupplyRequest(), metadata=metadata)
        return response.supply

    def query_supply_of(self, denom: str, height: Optional[int] = 0) -> Coin:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = BankClient(self.channel).SupplyOf(QuerySupplyOfRequest(denom=denom), metadata=metadata)
        return response.amount

    def query_validators(self, height: Optional[int] = 0) -> [Validator]:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = StakingClient(self.channel).Validators(QueryValidatorsRequest(), metadata=metadata)
        return response.validators

    def query_staking_params(self) -> StakingParams:
        response = StakingClient(self.channel).Params(QueryStakingParamsRequest())
        return response.params

    def query_gas_prices(self) -> [Coin]:
        response = CosmosNodeClient(self.channel).Config(ConfigRequest())
        return parse_coins(response.minimum_gas_price)

    def query_block_by_height(self, height: int) -> Block:
        response = TendermintClient(self.channel).GetBlockByHeight(GetBlockByHeightRequest(height=height))
        return response.block

    def query_latest_block(self) -> Block:
        response = TendermintClient(self.channel).GetLatestBlock(GetLatestBlockRequest())
        return response.block

    def query_chain_id(self) -> str:
        return self.query_node_info().network

    def query_node_syncing(self) -> bool:
        response = TendermintClient(self.channel).GetSyncing(GetSyncingRequest())
        return response.syncing

    def query_node_info(self) -> DefaultNodeInfo:
        response = TendermintClient(self.channel).GetNodeInfo(GetNodeInfoRequest())
        return response.default_node_info

    def avg_block_time_interval(self, block_interval: int = 2000) -> float:
        latest_block = self.query_latest_block()
        latest_block_height = latest_block.header.height
        latest_block_time = latest_block.header.time.seconds
        if latest_block_height > block_interval:
            block = self.query_block_by_height(latest_block_height - block_interval)
        else:
            block = self.query_block_by_height(1)
            block_interval = latest_block_height - 1
        block_time = block.header.time.seconds
        block_time_interval = (latest_block_time - block_time) / block_interval
        return float(format(block_time_interval, '.3f'))

    def query_tx(self, tx_hash: str) -> GetTxResponse:
        return TxClient(self.channel).GetTx(GetTxRequest(hash=tx_hash))

    def query_txs_by_event(self, events, order_by: OrderBy, page: int, limit: int) -> GetTxsEventResponse:
        return TxClient(self.channel).GetTxsEvent(GetTxsEventRequest(
            events=events, order_by=order_by, page=page, limit=limit
        ))

    def bank_send(self, tx_builder: TxBuilder, to: str, amount: [Coin],
                  mode: BroadcastMode = BROADCAST_MODE_SYNC) -> TxResponse:
        from_address = tx_builder.from_address().to_string()
        msg = new_msg_send(from_address=from_address, to_address=to, amount=amount)
        tx = self.build_tx(tx_builder, [msg])
        return self.broadcast_tx(tx, mode)

    def build_tx(self, tx_builder: TxBuilder, msgs: [Any], account_number: int = -1,
                 sequence: int = -1, gas_limit: int = 0) -> Tx:
        if tx_builder.chain_id == '':
            tx_builder.chain_id = self.query_chain_id()

        if account_number < 0 or sequence < 0:
            from_address = tx_builder.from_address().to_string()
            account = self.query_account_info(address=from_address)
            account_number = account.account_number
            sequence = account.sequence

        if tx_builder.has_gas_price() is False:
            gas_prices = self.query_gas_prices()
            tx_builder.with_gas_price(gas_prices)
        gas_fee_denom = tx_builder.gas_price.denom
        gas_price_amount = float(tx_builder.gas_price.amount)

        if gas_limit <= 0:
            gas_limit = DefGasLimit
            fee_amount = Coin(amount=str(int(gas_limit * gas_price_amount)), denom=gas_fee_denom)
            fee = Fee(amount=[fee_amount], gas_limit=gas_limit)
            tx = tx_builder.sign(msgs, fee, account_number, sequence)

            gas_info = self.estimating_gas(tx)
            gas_limit = int(float(gas_info.gas_used) * DefGasAdjustment)

        fee_amount = Coin(amount=str(int(gas_limit * gas_price_amount)), denom=gas_fee_denom)
        fee = Fee(amount=[fee_amount], gas_limit=gas_limit)
        return tx_builder.sign(msgs, fee, account_number, sequence)

    def estimating_gas(self, tx: Tx) -> GasInfo:
        response = TxClient(self.channel).Simulate(SimulateRequest(tx=tx))
        return response.gas_info

    def broadcast_tx(self, tx: Tx, mode: BroadcastMode = BROADCAST_MODE_SYNC) -> TxResponse:
        tx_raw = TxRaw(body_bytes=tx.body.SerializeToString(),
                       auth_info_bytes=tx.auth_info.SerializeToString(),
                       signatures=tx.signatures)
        tx_bytes = tx_raw.SerializeToString()
        response = TxClient(self.channel).BroadcastTx(
            BroadcastTxRequest(tx_bytes=tx_bytes, mode=mode))
        return response.tx_response

    def build_and_broadcast_tx(self, tx_builder: TxBuilder, msgs: [Any], account_number: int = -1, sequence: int = -1,
                               gas_limit: int = 0, mode: BroadcastMode = BROADCAST_MODE_SYNC) -> TxResponse:
        tx = self.build_tx(tx_builder, msgs, account_number, sequence, gas_limit)
        return self.broadcast_tx(tx, mode)

    def wait_mint_tx(self, tx_hash: str, timeout: int = 5, poll_interval: int = 1) -> TxResponse:
        for i in range(timeout // poll_interval):
            time.sleep(poll_interval)
            try:
                response = self.query_tx(tx_hash)
                return response.tx_response
            except grpc.RpcError:
                continue
        raise Exception("not found tx")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: marginx/oracle/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from fxsdk.x.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from fxsdk.x.marginx.oracle.v1 import types_pb2 as marginx_dot_oracle_dot_v1_dot_types__pb2
from fxsdk.x.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmarginx/oracle/v1/query.proto\x12\x11marginx.oracle.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\x1a\x1dmarginx/oracle/v1/types.proto\x1a\x19\x63osmos_proto/cosmos.proto\"%\n\x12QueryMarketRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\"F\n\x13QueryMarketResponse\x12/\n\x06market\x18\x01 \x01(\x0b\x32\x19.marginx.oracle.v1.MarketB\x04\xc8\xde\x1f\x00\"\x15\n\x13QueryMarketsRequest\"H\n\x14QueryMarketsResponse\x12\x30\n\x07markets\x18\x01 \x03(\x0b\x32\x19.marginx.oracle.v1.MarketB\x04\xc8\xde\x1f\x00\"$\n\x11QueryPriceRequest\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\"V\n\x12QueryPriceResponse\x12@\n\x05price\x18\x01 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"\x14\n\x12QueryPricesRequest\"^\n\tPairPrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12@\n\x05price\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"I\n\x13QueryPricesResponse\x12\x32\n\x06prices\x18\x01 \x03(\x0b\x32\x1c.marginx.oracle.v1.PairPriceB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"F\n\x13QueryParamsResponse\x12/\n\x06params\x18\x01 \x01(\x0b\x32\x19.marginx.oracle.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryAggregatorsRequest\"T\n\x18QueryAggregatorsResponse\x12\x38\n\x0b\x61ggregators\x18\x01 \x03(\x0b\x32\x1d.marginx.oracle.v1.AggregatorB\x04\xc8\xde\x1f\x00\x32\x95\x06\n\x05Query\x12~\n\x07Markets\x12&.marginx.oracle.v1.QueryMarketsRequest\x1a\'.marginx.oracle.v1.QueryMarketsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/marginx/oracle/v1/markets\x12z\n\x06Market\x12%.marginx.oracle.v1.QueryMarketRequest\x1a&.marginx.oracle.v1.QueryMarketResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/marginx/oracle/v1/market\x12~\n\x05Price\x12$.marginx.oracle.v1.QueryPriceRequest\x1a%.marginx.oracle.v1.QueryPriceResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /marginx/oracle/v1/current_price\x12\x82\x01\n\x06Prices\x12%.marginx.oracle.v1.QueryPricesRequest\x1a&.marginx.oracle.v1.QueryPricesResponse\")\x82\xd3\xe4\x93\x02#\x12!/marginx/oracle/v1/current_prices\x12z\n\x06Params\x12%.marginx.oracle.v1.QueryParamsRequest\x1a&.marginx.oracle.v1.QueryParamsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/marginx/oracle/v1/params\x12\x8e\x01\n\x0b\x41ggregators\x12*.marginx.oracle.v1.QueryAggregatorsRequest\x1a+.marginx.oracle.v1.QueryAggregatorsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/marginx/oracle/v1/aggregatorsB-Z+github.com/marginxio/marginx/x/oracle/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'marginx.oracle.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/marginxio/marginx/x/oracle/types'
  _QUERYMARKETRESPONSE.fields_by_name['market']._options = None
  _QUERYMARKETRESPONSE.fields_by_name['market']._serialized_options = b'\310\336\037\000'
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._options = None
  _QUERYMARKETSRESPONSE.fields_by_name['markets']._serialized_options = b'\310\336\037\000'
  _QUERYPRICERESPONSE.fields_by_name['price']._options = None
  _QUERYPRICERESPONSE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _PAIRPRICE.fields_by_name['price']._options = None
  _PAIRPRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _QUERYPRICESRESPONSE.fields_by_name['prices']._options = None
  _QUERYPRICESRESPONSE.fields_by_name['prices']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATORSRESPONSE.fields_by_name['aggregators']._options = None
  _QUERYAGGREGATORSRESPONSE.fields_by_name['aggregators']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Markets']._options = None
  _QUERY.methods_by_name['Markets']._serialized_options = b'\202\323\344\223\002\034\022\032/marginx/oracle/v1/markets'
  _QUERY.methods_by_name['Market']._options = None
  _QUERY.methods_by_name['Market']._serialized_options = b'\202\323\344\223\002\033\022\031/marginx/oracle/v1/market'
  _QUERY.methods_by_name['Price']._options = None
  _QUERY.methods_by_name['Price']._serialized_options = b'\202\323\344\223\002\"\022 /marginx/oracle/v1/current_price'
  _QUERY.methods_by_name['Prices']._options = None
  _QUERY.methods_by_name['Prices']._serialized_options = b'\202\323\344\223\002#\022!/marginx/oracle/v1/current_prices'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\033\022\031/marginx/oracle/v1/params'
  _QUERY.methods_by_name['Aggregators']._options = None
  _QUERY.methods_by_name['Aggregators']._serialized_options = b'\202\323\344\223\002 \022\036/marginx/oracle/v1/aggregators'
  _globals['_QUERYMARKETREQUEST']._serialized_start=162
  _globals['_QUERYMARKETREQUEST']._serialized_end=199
  _globals['_QUERYMARKETRESPONSE']._serialized_start=201
  _globals['_QUERYMARKETRESPONSE']._serialized_end=271
  _globals['_QUERYMARKETSREQUEST']._serialized_start=273
  _globals['_QUERYMARKETSREQUEST']._serialized_end=294
  _globals['_QUERYMARKETSRESPONSE']._serialized_start=296
  _globals['_QUERYMARKETSRESPONSE']._serialized_end=368
  _globals['_QUERYPRICEREQUEST']._serialized_start=370
  _globals['_QUERYPRICEREQUEST']._serialized_end=406
  _globals['_QUERYPRICERESPONSE']._serialized_start=408
  _globals['_QUERYPRICERESPONSE']._serialized_end=494
  _globals['_QUERYPRICESREQUEST']._serialized_start=496
  _globals['_QUERYPRICESREQUEST']._serialized_end=516
  _globals['_PAIRPRICE']._serialized_start=518
  _globals['_PAIRPRICE']._serialized_end=612
  _globals['_QUERYPRICESRESPONSE']._serialized_start=614
  _globals['_QUERYPRICESRESPONSE']._serialized_end=687
  _globals['_QUERYPARAMSREQUEST']._serialized_start=689
  _globals['_QUERYPARAMSREQUEST']._serialized_end=709
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=711
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=781
  _globals['_QUERYAGGREGATORSREQUEST']._serialized_start=783
  _globals['_QUERYAGGREGATORSREQUEST']._serialized_end=808
  _globals['_QUERYAGGREGATORSRESPONSE']._serialized_start=810
  _globals['_QUERYAGGREGATORSRESPONSE']._serialized_end=894
  _globals['_QUERY']._serialized_start=897
  _globals['_QUERY']._serialized_end=1686
# @@protoc_insertion_point(module_scope)



import unittest
from decimal import Decimal

from fxsdk.dec import dec_to_str, dec_from_str


class TestDecCase(unittest.TestCase):
    def test_dec_to_str(self):
        res = dec_to_str(Decimal('1.000000000000000000'))
        self.assertEqual(res, '1000000')

    def test_dec_from_str(self):
        res = dec_from_str('1.000000000000000000')
        self.assertEqual(res, Decimal('0.000001000000000000'))


if __name__ == '__main__':
    unittest.main()



from enum import Enum
from typing import Optional

import requests
from eth_utils import is_hex_address

from fxsdk.client.grpc import Client, GRPCBlockHeightHeader
from fxsdk.msg import new_ibc_fx_msg_transfer
from fxsdk.wallet.builder import TxBuilder
from fxsdk.x.cosmos.base.v1beta1.coin_pb2 import Coin
from fxsdk.x.cosmos.tx.v1beta1.service_pb2 import BroadcastMode, BROADCAST_MODE_UNSPECIFIED
from fxsdk.x.ibc.core.channel.v1.channel_pb2 import Channel, IdentifiedChannel
from fxsdk.x.ibc.core.channel.v1.query_pb2 import QueryChannelRequest, QueryChannelsRequest
from fxsdk.x.ibc.core.channel.v1.query_pb2_grpc import QueryStub as IbcChannelClient


class CrossChainTarget(Enum):
    Ethereum = 'ethereum'
    MarginX = 'marginx'
    FxCore = 'fxcore'


bridge_fee_api = "https://starscan.io/explorer/gravity/v2/fee/search"


class BridgeFee:

    def __init__(self, url: str = bridge_fee_api):
        self._url = url

    def _get_api(self, chain_id: str, denom: str) -> str:
        if denom == 'FX':
            token_contract = '0x8c15ef5b4b21951d50e53e4fbda8298ffad25057'
        elif denom == 'USDT':
            token_contract = '0xdac17f958d2ee523a2206206994597c13d831ec7'
        else:
            raise Exception("denom not supported")
        api = '{}?chainId={}&tokenContract={}'.format(self._url, chain_id, token_contract)
        return api

    def get_fast(self, chain_id: str, denom: str) -> int:
        result = requests.get(self._get_api(chain_id, denom))
        return result.json()['data']['rapid']

    def get_standard(self, chain_id: str, denom: str) -> int:
        result = requests.get(self._get_api(chain_id, denom))
        return result.json()['data']['standard']


class CrossChainClient(Client, BridgeFee):

    def __init__(self, url: str = 'localhost:9090'):
        super().__init__(url)
        BridgeFee.__init__(self)

    def query_channel(self, channel_id: str, height: Optional[int] = 0) -> Channel:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = IbcChannelClient(self.channel).Channel(
            QueryChannelRequest(port_id='transfer', channel_id=channel_id), metadata=metadata)
        return response.channel

    def query_channels(self, height: Optional[int] = 0) -> [IdentifiedChannel]:
        metadata = [(GRPCBlockHeightHeader, str(height))]
        response = IbcChannelClient(self.channel).Channels(QueryChannelsRequest(), metadata=metadata)
        return response.channels

    def ibc_transfer(self, tx_builder: TxBuilder, to_address: str, amount: Coin, channel: str, target: CrossChainTarget,
                     mode: Optional[BroadcastMode] = BROADCAST_MODE_UNSPECIFIED):
        router = ''
        fee = Coin(denom=amount.denom, amount='0')
        if target is CrossChainTarget.Ethereum:
            router = 'eth'
            fee.amount = self.get_fast(target.value, amount.denom)
        elif target is CrossChainTarget.MarginX:
            pass
        elif target is CrossChainTarget.FxCore:
            if is_hex_address(to_address) is False:
                raise Exception("address should be hex format")
        else:
            raise Exception("target chain not supported")
        sender = tx_builder.from_address().to_string()
        msg = new_ibc_fx_msg_transfer(channel=channel, sender=sender, receiver=to_address, token=amount,
                                      router=router, fee=fee)
        if mode is BROADCAST_MODE_UNSPECIFIED or mode is None:
            return self.build_tx(tx_builder=tx_builder, msgs=[msg])
        else:
            return self.build_and_broadcast_tx(tx_builder=tx_builder, msgs=[msg], mode=mode)

    def ibc_transfer_mx2mx(self, tx_builder: TxBuilder, amount: Coin, from_channel: str, to_channel: str,
                           mode: Optional[BroadcastMode] = BROADCAST_MODE_UNSPECIFIED):
        address = tx_builder.from_address()
        to_address = "{}|transfer/{}:{}".format(address.to_string("fx"), to_channel, address.to_string())
        self.ibc_transfer(tx_builder=tx_builder, to_address=to_address, amount=amount, channel=from_channel,
                          target=CrossChainTarget.MarginX, mode=mode)
